@@ -4,9 +4,11 @@ import time
 import aiohttp
 from aiohttp import ClientSession
 
+from pymax.exceptions import Error
 from pymax.files import File, Photo
 from pymax.formatting import Formatting
 from pymax.interfaces import ClientProtocol
+from pymax.mixins.utils import MixinsUtils
 from pymax.payloads import (
     AddReactionPayload,
     AttachFilePayload,
@@ -46,9 +48,8 @@ class MessageMixin(ClientProtocol):
                 opcode=Opcode.FILE_UPLOAD,
                 payload=payload,
             )
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Upload file error: %s", error)
-                return None
+            if data.get("payload", {}).get("error"):
+                MixinsUtils.handle_error(data)
 
             url = data.get("payload", {}).get("info", [None])[0].get("url", None)
             file_id = data.get("payload", {}).get("info", [None])[0].get("fileId", None)
@@ -107,9 +108,9 @@ class MessageMixin(ClientProtocol):
                 opcode=Opcode.PHOTO_UPLOAD,
                 payload=payload,
             )
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Upload photo error: %s", error)
-                return None
+
+            if data.get("payload", {}).get("error"):
+                MixinsUtils.handle_error(data)
 
             url = data.get("payload", {}).get("url")
             if not url:
@@ -189,77 +190,79 @@ class MessageMixin(ClientProtocol):
         """
         Отправляет сообщение в чат.
         """
-        try:
-            self.logger.info("Sending message to chat_id=%s notify=%s", chat_id, notify)
-            if attachments and attachment:
-                self.logger.warning("Both photo and photos provided; using photos")
-                attachment = None
-            attaches = []
-            if attachment:
-                self.logger.info("Uploading attachment for message")
-                result = await self._upload_attachment(attachment)
-                if not result:
-                    self.logger.error("Attachment upload failed, message not sent")
-                    return None
-                attaches.append(result)
 
-            elif attachments:
-                self.logger.info("Uploading multiple attachments for message")
-                for p in attachments:
-                    result = await self._upload_attachment(p)
-                    if result:
-                        attaches.append(result)
-                    else:
-                        self.logger.error("One of attachments upload failed")
+        self.logger.info("Sending message to chat_id=%s notify=%s", chat_id, notify)
+        if attachments and attachment:
+            self.logger.warning("Both photo and photos provided; using photos")
+            attachment = None
 
-                if not attaches:
-                    self.logger.error(
-                        "All attachments uploads failed, message not sent"
+        attaches = []
+        if attachment:
+            self.logger.info("Uploading attachment for message")
+            result = await self._upload_attachment(attachment)
+            if not result:
+                raise Error(
+                    "upload_failed", "Failed to upload attachment", "Upload Error"
+                )
+            attaches.append(result)
+
+        elif attachments:
+            self.logger.info("Uploading multiple attachments for message")
+            for p in attachments:
+                result = await self._upload_attachment(p)
+                if result:
+                    attaches.append(result)
+                else:
+                    raise Error(
+                        "upload_failed", "Failed to upload attachment", "Upload Error"
                     )
-                    return None
 
-            elements = []
-            clean_text = None
-            raw_elements = Formatting.get_elements_from_markdown(text)[0]
-            if raw_elements:
-                clean_text = Formatting.get_elements_from_markdown(text)[1]
-            elements = [
-                MessageElement(type=e.type, length=e.length, from_=e.from_)
-                for e in raw_elements
-            ]
-
-            payload = SendMessagePayload(
-                chat_id=chat_id,
-                message=SendMessagePayloadMessage(
-                    text=clean_text if clean_text else text,
-                    cid=int(time.time() * 1000),
-                    elements=elements,
-                    attaches=attaches,
-                    link=(ReplyLink(message_id=str(reply_to)) if reply_to else None),
-                ),
-                notify=notify,
-            ).model_dump(by_alias=True)
-
-            if use_queue:
-                await self._queue_message(opcode=Opcode.MSG_SEND, payload=payload)
-                self.logger.debug("Message queued for sending")
-                return None
-            else:
-                data = await self._send_and_wait(
-                    opcode=Opcode.MSG_SEND, payload=payload
+            if not attaches:
+                raise Error(
+                    "upload_failed", "All attachments failed to upload", "Upload Error"
                 )
-                if error := data.get("payload", {}).get("error"):
-                    self.logger.error("Send message error: %s", error)
-                    return None
-                msg = (
-                    Message.from_dict(data["payload"]) if data.get("payload") else None
-                )
-                self.logger.debug("send_message result: %r", msg)
-                return msg
-        except Exception:
-            self.logger.exception("Send message failed")
+
+        elements = []
+        clean_text = None
+        raw_elements = Formatting.get_elements_from_markdown(text)[0]
+        if raw_elements:
+            clean_text = Formatting.get_elements_from_markdown(text)[1]
+        elements = [
+            MessageElement(type=e.type, length=e.length, from_=e.from_)
+            for e in raw_elements
+        ]
+
+        payload = SendMessagePayload(
+            chat_id=chat_id,
+            message=SendMessagePayloadMessage(
+                text=clean_text if clean_text else text,
+                cid=int(time.time() * 1000),
+                elements=elements,
+                attaches=attaches,
+                link=(ReplyLink(message_id=str(reply_to)) if reply_to else None),
+            ),
+            notify=notify,
+        ).model_dump(by_alias=True)
+
+        if use_queue:
+            await self._queue_message(opcode=Opcode.MSG_SEND, payload=payload)
+            self.logger.debug("Message queued for sending")
             return None
 
+        data = await self._send_and_wait(opcode=Opcode.MSG_SEND, payload=payload)
+
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        msg = Message.from_dict(data["payload"]) if data.get("payload") else None
+        self.logger.debug("send_message result: %r", msg)
+        if not msg:
+            raise Error(
+                "no_message", "Message data missing in response", "Message Error"
+            )
+
+        return msg
+
     async def edit_message(
         self,
         chat_id: int,
@@ -269,74 +272,76 @@ class MessageMixin(ClientProtocol):
         attachments: list[Photo] | None = None,
         use_queue: bool = False,
     ) -> Message | None:
-        try:
-            self.logger.info(
-                "Editing message chat_id=%s message_id=%s", chat_id, message_id
+        self.logger.info(
+            "Editing message chat_id=%s message_id=%s", chat_id, message_id
+        )
+
+        if attachments and attachment:
+            self.logger.warning("Both photo and photos provided; using photos")
+            attachment = None
+
+        attaches = []
+        if attachment:
+            self.logger.info("Uploading attachment for message")
+            result = await self._upload_attachment(attachment)
+            if not result:
+                raise Error(
+                    "upload_failed", "Failed to upload attachment", "Upload Error"
+                )
+            attaches.append(result)
+
+        elif attachments:
+            self.logger.info("Uploading multiple attachments for message")
+            for p in attachments:
+                result = await self._upload_attachment(p)
+                if result:
+                    attaches.append(result)
+                else:
+                    raise Error(
+                        "upload_failed", "Failed to upload attachment", "Upload Error"
+                    )
+
+            if not attaches:
+                raise Error(
+                    "upload_failed", "All attachments failed to upload", "Upload Error"
+                )
+
+        elements = []
+        clean_text = None
+        raw_elements = Formatting.get_elements_from_markdown(text)[0]
+        if raw_elements:
+            clean_text = Formatting.get_elements_from_markdown(text)[1]
+        elements = [
+            MessageElement(type=e.type, length=e.length, from_=e.from_)
+            for e in raw_elements
+        ]
+
+        payload = EditMessagePayload(
+            chat_id=chat_id,
+            message_id=message_id,
+            text=clean_text if clean_text else text,
+            elements=elements,
+            attaches=attaches,
+        ).model_dump(by_alias=True)
+
+        if use_queue:
+            await self._queue_message(opcode=Opcode.MSG_EDIT, payload=payload)
+            self.logger.debug("Edit message queued for sending")
+            return None
+
+        data = await self._send_and_wait(opcode=Opcode.MSG_EDIT, payload=payload)
+
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        msg = Message.from_dict(data["payload"]) if data.get("payload") else None
+        self.logger.debug("edit_message result: %r", msg)
+        if not msg:
+            raise Error(
+                "no_message", "Message data missing in response", "Message Error"
             )
 
-            if attachments and attachment:
-                self.logger.warning("Both photo and photos provided; using photos")
-                attachment = None
-            attaches = []
-            if attachment:
-                self.logger.info("Uploading attachment for message")
-                result = await self._upload_attachment(attachment)
-                if not result:
-                    self.logger.error("Attachment upload failed, message not sent")
-                    return None
-                attaches.append(result)
-
-            elif attachments:
-                self.logger.info("Uploading multiple attachments for message")
-                for p in attachment:
-                    result = await self._upload_attachment(p)
-                    if result:
-                        attaches.append(result)
-                    else:
-                        self.logger.error("One of attachments upload failed")
-
-                if not attaches:
-                    self.logger.error(
-                        "All attachments uploads failed, message not sent"
-                    )
-                    return None
-
-            elements = []
-            clean_text = None
-            raw_elements = Formatting.get_elements_from_markdown(text)[0]
-            if raw_elements:
-                clean_text = Formatting.get_elements_from_markdown(text)[1]
-            elements = [
-                MessageElement(type=e.type, length=e.length, from_=e.from_)
-                for e in raw_elements
-            ]
-
-            payload = EditMessagePayload(
-                chat_id=chat_id,
-                message_id=message_id,
-                text=clean_text if clean_text else text,
-                elements=elements,
-                attaches=attaches,
-            ).model_dump(by_alias=True)
-
-            if use_queue:
-                await self._queue_message(opcode=Opcode.MSG_EDIT, payload=payload)
-                self.logger.debug("Edit message queued for sending")
-                return None
-            else:
-                data = await self._send_and_wait(
-                    opcode=Opcode.MSG_EDIT, payload=payload
-                )
-                if error := data.get("payload", {}).get("error"):
-                    self.logger.error("Edit message error: %s", error)
-                msg = (
-                    Message.from_dict(data["payload"]) if data.get("payload") else None
-                )
-                self.logger.debug("edit_message result: %r", msg)
-                return msg
-        except Exception:
-            self.logger.exception("Edit message failed")
-            return None
+        return msg
 
     async def delete_message(
         self,
@@ -348,34 +353,29 @@ class MessageMixin(ClientProtocol):
         """
         Удаляет сообщения.
         """
-        try:
-            self.logger.info(
-                "Deleting messages chat_id=%s ids=%s for_me=%s",
-                chat_id,
-                message_ids,
-                for_me,
-            )
+        self.logger.info(
+            "Deleting messages chat_id=%s ids=%s for_me=%s",
+            chat_id,
+            message_ids,
+            for_me,
+        )
 
-            payload = DeleteMessagePayload(
-                chat_id=chat_id, message_ids=message_ids, for_me=for_me
-            ).model_dump(by_alias=True)
+        payload = DeleteMessagePayload(
+            chat_id=chat_id, message_ids=message_ids, for_me=for_me
+        ).model_dump(by_alias=True)
 
-            if use_queue:
-                await self._queue_message(opcode=Opcode.MSG_DELETE, payload=payload)
-                self.logger.debug("Delete message queued for sending")
-                return True
-            else:
-                data = await self._send_and_wait(
-                    opcode=Opcode.MSG_DELETE, payload=payload
-                )
-                if error := data.get("payload", {}).get("error"):
-                    self.logger.error("Delete message error: %s", error)
-                    return False
-                self.logger.debug("delete_message success")
-                return True
-        except Exception:
-            self.logger.exception("Delete message failed")
-            return False
+        if use_queue:
+            await self._queue_message(opcode=Opcode.MSG_DELETE, payload=payload)
+            self.logger.debug("Delete message queued for sending")
+            return True
+
+        data = await self._send_and_wait(opcode=Opcode.MSG_DELETE, payload=payload)
+
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        self.logger.debug("delete_message success")
+        return True
 
     async def pin_message(
         self, chat_id: int, message_id: int, notify_pin: bool
@@ -391,22 +391,19 @@ class MessageMixin(ClientProtocol):
         Returns:
             bool: True, если сообщение закреплено
         """
-        try:
-            payload = PinMessagePayload(
-                chat_id=chat_id,
-                notify_pin=notify_pin,
-                pin_message_id=message_id,
-            ).model_dump(by_alias=True)
+        payload = PinMessagePayload(
+            chat_id=chat_id,
+            notify_pin=notify_pin,
+            pin_message_id=message_id,
+        ).model_dump(by_alias=True)
 
-            data = await self._send_and_wait(opcode=Opcode.CHAT_UPDATE, payload=payload)
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Pin message error: %s", error)
-                return False
-            self.logger.debug("pin_message success")
-            return True
-        except Exception:
-            self.logger.exception("Pin message failed")
-            return False
+        data = await self._send_and_wait(opcode=Opcode.CHAT_UPDATE, payload=payload)
+
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        self.logger.debug("pin_message success")
+        return True
 
     async def fetch_history(
         self,
@@ -421,40 +418,35 @@ class MessageMixin(ClientProtocol):
         if from_time is None:
             from_time = int(time.time() * 1000)
 
-        try:
-            self.logger.info(
-                "Fetching history chat_id=%s from=%s forward=%s backward=%s",
-                chat_id,
-                from_time,
-                forward,
-                backward,
-            )
+        self.logger.info(
+            "Fetching history chat_id=%s from=%s forward=%s backward=%s",
+            chat_id,
+            from_time,
+            forward,
+            backward,
+        )
 
-            payload = FetchHistoryPayload(
-                chat_id=chat_id,
-                from_time=from_time,
-                forward=forward,
-                backward=backward,
-            ).model_dump(by_alias=True)
+        payload = FetchHistoryPayload(
+            chat_id=chat_id,
+            from_time=from_time,
+            forward=forward,
+            backward=backward,
+        ).model_dump(by_alias=True)
 
-            self.logger.debug("Payload dict keys: %s", list(payload.keys()))
+        self.logger.debug("Payload dict keys: %s", list(payload.keys()))
 
-            data = await self._send_and_wait(
-                opcode=Opcode.CHAT_HISTORY, payload=payload, timeout=10
-            )
+        data = await self._send_and_wait(
+            opcode=Opcode.CHAT_HISTORY, payload=payload, timeout=10
+        )
 
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Fetch history error: %s", error)
-                return None
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
 
-            messages = [
-                Message.from_dict(msg) for msg in data["payload"].get("messages", [])
-            ]
-            self.logger.debug("History fetched: %d messages", len(messages))
-            return messages
-        except Exception:
-            self.logger.exception("Fetch history failed")
-            return None
+        messages = [
+            Message.from_dict(msg) for msg in data["payload"].get("messages", [])
+        ]
+        self.logger.debug("History fetched: %d messages", len(messages))
+        return messages
 
     async def get_video_by_id(
         self,
@@ -475,34 +467,30 @@ class MessageMixin(ClientProtocol):
             cache (bool): True, если видео кэшировано
             url (str): Ссылка на видео
         """
-        try:
-            self.logger.info("Getting video_id=%s message_id=%s", video_id, message_id)
+        self.logger.info("Getting video_id=%s message_id=%s", video_id, message_id)
 
-            if self.is_connected and self._socket is not None:
-                payload = GetVideoPayload(
-                    chat_id=chat_id, message_id=message_id, video_id=video_id
-                ).model_dump(by_alias=True)
-            else:
-                payload = GetVideoPayload(
-                    chat_id=chat_id,
-                    message_id=str(message_id),
-                    video_id=video_id,
-                ).model_dump(by_alias=True)
+        if self.is_connected and self._socket is not None:
+            payload = GetVideoPayload(
+                chat_id=chat_id, message_id=message_id, video_id=video_id
+            ).model_dump(by_alias=True)
+        else:
+            payload = GetVideoPayload(
+                chat_id=chat_id,
+                message_id=str(message_id),
+                video_id=video_id,
+            ).model_dump(by_alias=True)
 
             data = await self._send_and_wait(opcode=Opcode.VIDEO_PLAY, payload=payload)
 
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Get video error: %s", error)
-                return None
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
 
-            video = (
-                VideoRequest.from_dict(data["payload"]) if data.get("payload") else None
-            )
-            self.logger.debug("result: %r", video)
-            return video
-        except Exception:
-            self.logger.exception("Get video error")
-            return None
+        video = VideoRequest.from_dict(data["payload"]) if data.get("payload") else None
+        self.logger.debug("result: %r", video)
+        if not video:
+            raise Error("no_video", "Video data missing in response", "Video Error")
+
+        return video
 
     async def get_file_by_id(
         self,
@@ -522,34 +510,29 @@ class MessageMixin(ClientProtocol):
             unsafe (bool): Проверка файла на безопасность максом
             url (str): Ссылка на скачивание файла
         """
-        try:
-            self.logger.info("Getting file_id=%s message_id=%s", file_id, message_id)
-            if self.is_connected and self._socket is not None:
-                payload = GetFilePayload(
-                    chat_id=chat_id, message_id=message_id, file_id=file_id
-                ).model_dump(by_alias=True)
-            else:
-                payload = GetFilePayload(
-                    chat_id=chat_id,
-                    message_id=str(message_id),
-                    file_id=file_id,
-                ).model_dump(by_alias=True)
-            data = await self._send_and_wait(
-                opcode=Opcode.FILE_DOWNLOAD, payload=payload
-            )
+        self.logger.info("Getting file_id=%s message_id=%s", file_id, message_id)
+        if self.is_connected and self._socket is not None:
+            payload = GetFilePayload(
+                chat_id=chat_id, message_id=message_id, file_id=file_id
+            ).model_dump(by_alias=True)
+        else:
+            payload = GetFilePayload(
+                chat_id=chat_id,
+                message_id=str(message_id),
+                file_id=file_id,
+            ).model_dump(by_alias=True)
 
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Get file error: %s", error)
-                return None
+        data = await self._send_and_wait(opcode=Opcode.FILE_DOWNLOAD, payload=payload)
 
-            file = (
-                FileRequest.from_dict(data["payload"]) if data.get("payload") else None
-            )
-            self.logger.debug(" result: %r", file)
-            return file
-        except Exception:
-            self.logger.exception("Get video error")
-            return None
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        file = FileRequest.from_dict(data["payload"]) if data.get("payload") else None
+        self.logger.debug(" result: %r", file)
+        if not file:
+            raise Error("no_file", "File data missing in response", "File Error")
+
+        return file
 
     async def add_reaction(
         self,
@@ -585,9 +568,9 @@ class MessageMixin(ClientProtocol):
             data = await self._send_and_wait(
                 opcode=Opcode.MSG_REACTION, payload=payload
             )
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Add reaction error: %s", error)
-                return None
+
+            if data.get("payload", {}).get("error"):
+                MixinsUtils.handle_error(data)
 
             self.logger.debug("add_reaction success")
             return (
@@ -610,39 +593,34 @@ class MessageMixin(ClientProtocol):
             message_ids (list[str]): Список ID сообщений
 
         Returns:
-            dict[str, ReactionInfo] | None: Словарь с ID сообщений и информацией о реакциях или None при ошибке.
+            dict[str, ReactionInfo] | None: Словарь с ID сообщений и информацией
+            о реакциях или None при ошибке.
         """
-        try:
-            self.logger.info(
-                "Getting reactions for messages chat_id=%s message_ids=%s",
-                chat_id,
-                message_ids,
-            )
+        self.logger.info(
+            "Getting reactions for messages chat_id=%s message_ids=%s",
+            chat_id,
+            message_ids,
+        )
 
-            payload = GetReactionsPayload(
-                chat_id=chat_id, message_ids=message_ids
-            ).model_dump(by_alias=True)
+        payload = GetReactionsPayload(
+            chat_id=chat_id, message_ids=message_ids
+        ).model_dump(by_alias=True)
 
-            data = await self._send_and_wait(
-                opcode=Opcode.MSG_GET_REACTIONS, payload=payload
-            )
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Get reactions error: %s", error)
-                return None
+        data = await self._send_and_wait(
+            opcode=Opcode.MSG_GET_REACTIONS, payload=payload
+        )
 
-            reactions = {}
-            for msg_id, reaction_data in (
-                data.get("payload", {}).get("messagesReactions", {}).items()
-            ):
-                reactions[msg_id] = ReactionInfo.from_dict(reaction_data)
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
 
-            self.logger.debug("get_reactions success")
+        reactions = {}
+        for msg_id, reaction_data in (
+            data.get("payload", {}).get("messagesReactions", {}).items()
+        ):
+            reactions[msg_id] = ReactionInfo.from_dict(reaction_data)
 
-            return reactions
-
-        except Exception:
-            self.logger.exception("Get reactions failed")
-            return None
+        self.logger.debug("get_reactions success")
+        return reactions
 
     async def remove_reaction(
         self,
@@ -659,31 +637,36 @@ class MessageMixin(ClientProtocol):
         Returns:
             ReactionInfo | None: Информация о реакции или None при ошибке.
         """
-        try:
-            self.logger.info(
-                "Removing reaction from message chat_id=%s message_id=%s",
-                chat_id,
-                message_id,
+        self.logger.info(
+            "Removing reaction from message chat_id=%s message_id=%s",
+            chat_id,
+            message_id,
+        )
+
+        payload = RemoveReactionPayload(
+            chat_id=chat_id,
+            message_id=message_id,
+        ).model_dump(by_alias=True)
+
+        data = await self._send_and_wait(
+            opcode=Opcode.MSG_CANCEL_REACTION, payload=payload
+        )
+
+        if data.get("payload", {}).get("error"):
+            MixinsUtils.handle_error(data)
+
+        self.logger.debug("remove_reaction success")
+        if not data.get("payload"):
+            raise Error(
+                "no_reaction", "Reaction data missing in response", "Reaction Error"
             )
 
-            payload = RemoveReactionPayload(
-                chat_id=chat_id,
-                message_id=message_id,
-            ).model_dump(by_alias=True)
-
-            data = await self._send_and_wait(
-                opcode=Opcode.MSG_CANCEL_REACTION, payload=payload
+        reaction = ReactionInfo.from_dict(data["payload"]["reactionInfo"])
+        if not reaction:
+            raise Error(
+                "invalid_reaction",
+                "Invalid reaction data in response",
+                "Reaction Error",
             )
-            if error := data.get("payload", {}).get("error"):
-                self.logger.error("Remove reaction error: %s", error)
-                return None
 
-            self.logger.debug("remove_reaction success")
-            return (
-                ReactionInfo.from_dict(data["payload"]["reactionInfo"])
-                if data.get("payload")
-                else None
-            )
-        except Exception:
-            self.logger.exception("Remove reaction failed")
-            return None
+        return reaction
