@@ -163,9 +163,7 @@ class Contact:
 
     @override
     def __str__(self) -> str:
-        return (
-            f"Contact {self.id}: {', '.join(str(n) for n in self.names or [])}"
-        )
+        return f"Contact {self.id}: {', '.join(str(n) for n in self.names or [])}"
 
 
 class Member:
@@ -279,9 +277,7 @@ class StickerAttach:
 
 
 class ControlAttach:
-    def __init__(
-        self, type: AttachType, event: str, **kwargs: dict[str, Any]
-    ) -> None:
+    def __init__(self, type: AttachType, event: str, **kwargs: dict[str, Any]) -> None:
         self.type = type
         self.event = event
         self.extra = kwargs
@@ -306,6 +302,50 @@ class ControlAttach:
         return f"ControlAttach: {self.event}"
 
 
+class AudioAttach:
+    def __init__(
+        self,
+        duration: int,
+        audio_id: int,
+        url: str,
+        wave: str,
+        transcription_status: str,  # TODO: сделать энам
+        token: str,
+        type: AttachType,
+    ) -> None:
+        self.duration = duration
+        self.audio_id = audio_id
+        self.url = url
+        self.wave = wave
+        self.transcription_status = transcription_status
+        self.token = token
+        self.type = type
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(
+            duration=data["duration"],
+            audio_id=data["audioId"],
+            url=data["url"],
+            wave=data["wave"],
+            transcription_status=data["transcriptionStatus"],
+            token=data["token"],
+            type=AttachType(data["_type"]),
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return (
+            f"AudioAttach(duration={self.duration!r}, audio_id={self.audio_id!r}, "
+            f"url={self.url!r}, wave={self.wave!r}, transcription_status={self.transcription_status!r}, "
+            f"token={self.token!r}, type={self.type!r})"
+        )
+
+    @override
+    def __str__(self) -> str:
+        return f"AudioAttach: {self.audio_id}"
+
+
 class PhotoAttach:
     def __init__(
         self,
@@ -522,13 +562,13 @@ class Element:
 
     @classmethod
     def from_dict(cls, data: dict[Any, Any]) -> Self:
-        return cls(
-            type=data["type"], length=data["length"], from_=data.get("from")
-        )
+        return cls(type=data["type"], length=data["length"], from_=data.get("from"))
 
     @override
     def __repr__(self) -> str:
-        return f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
+        return (
+            f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
+        )
 
     @override
     def __str__(self) -> str:
@@ -591,9 +631,7 @@ class ReactionInfo:
     def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             total_count=data.get("totalCount", 0),
-            counters=[
-                ReactionCounter.from_dict(c) for c in data.get("counters", [])
-            ],
+            counters=[ReactionCounter.from_dict(c) for c in data.get("counters", [])],
             your_reaction=data.get("yourReaction"),
         )
 
@@ -619,6 +657,7 @@ class Message:
                 | FileAttach
                 | ControlAttach
                 | StickerAttach
+                | AudioAttach
             ]
             | None
         ),
@@ -640,11 +679,7 @@ class Message:
     def from_dict(cls, data: dict[Any, Any]) -> Self:
         message = data["message"] if data.get("message") else data
         attaches: list[
-            PhotoAttach
-            | VideoAttach
-            | FileAttach
-            | ControlAttach
-            | StickerAttach
+            PhotoAttach | VideoAttach | FileAttach | ControlAttach | StickerAttach
         ] = []
         for a in message.get("attaches", []):
             if a["_type"] == AttachType.PHOTO:
@@ -657,6 +692,8 @@ class Message:
                 attaches.append(ControlAttach.from_dict(a))
             elif a["_type"] == AttachType.STICKER:
                 attaches.append(StickerAttach.from_dict(a))
+            elif a["_type"] == AttachType.AUDIO:
+                attaches.append(AudioAttach.from_dict(a))
         link_value = message.get("link")
         if isinstance(link_value, dict):
             link = MessageLink.from_dict(link_value)
@@ -670,9 +707,7 @@ class Message:
         return cls(
             chat_id=data.get("chatId"),
             sender=message.get("sender"),
-            elements=[
-                Element.from_dict(e) for e in message.get("elements", [])
-            ],
+            elements=[Element.from_dict(e) for e in message.get("elements", [])],
             options=message.get("options"),
             id=message["id"],
             time=message["time"],
@@ -834,13 +869,9 @@ class Chat:
             int(k): v for k, v in raw_admins.items()
         }
         raw_participants = data.get("participants", {}) or {}
-        participants: dict[int, int] = {
-            int(k): v for k, v in raw_participants.items()
-        }
+        participants: dict[int, int] = {int(k): v for k, v in raw_participants.items()}
         last_msg = (
-            Message.from_dict(data["lastMessage"])
-            if data.get("lastMessage")
-            else None
+            Message.from_dict(data["lastMessage"]) if data.get("lastMessage") else None
         )
         return cls(
             participants_count=data.get("participantsCount", 0),
@@ -852,9 +883,7 @@ class Chat:
             description=data.get("description"),
             chat_type=ChatType(data.get("type", ChatType.CHAT.value)),
             title=data.get("title"),
-            last_fire_delayed_error_time=data.get(
-                "lastFireDelayedErrorTime", 0
-            ),
+            last_fire_delayed_error_time=data.get("lastFireDelayedErrorTime", 0),
             last_delayed_update_time=data.get("lastDelayedUpdateTime", 0),
             options=data.get("options", {}),
             modified=data.get("modified", 0),
@@ -876,9 +905,7 @@ class Chat:
 
     @override
     def __repr__(self) -> str:
-        return (
-            f"Chat(id={self.id!r}, title={self.title!r}, type={self.type!r})"
-        )
+        return f"Chat(id={self.id!r}, title={self.title!r}, type={self.type!r})"
 
     @override
     def __str__(self) -> str:
